accuranker_competitor_ranks: Get the keyword rankings of your competitors for a specific...

Description Usage Arguments Examples

Description

Get the keyword rankings of your competitors for a specific domain

Usage

1
2
3
4
5
6
accuranker_competitor_ranks(
  domain_name,
  date_range = "TODAY",
  silent = FALSE,
  simple_token = NULL
)

Arguments

date_range

The time period for which to get rankings from

silent

If TRUE, nothing will be printed to the console

simple_token

Can be used to insert a custom API token instead of using oauth2.

domain_id

A specific domain id

Examples

1
accuranker_keywords(domain_name, date_range = "TODAY", silent = FALSE, simple_token = NULL)

lynuhs/accurankeR documentation built on Feb. 1, 2021, 6:47 a.m.