accuranker_domains: Get a list of all domains in the authorized Accuranker...

Description Usage Arguments Examples

View source: R/accuranker_domains.R

Description

Get a list of all domains in the authorized Accuranker account

Usage

1
accuranker_domains(simple_token = NULL)

Arguments

simple_token

Can be used to insert a custom API token instead of using oauth2.

Examples

1
accuranker_domains(simple_token = NULL)

lynuhs/accurankeR documentation built on Feb. 1, 2021, 6:47 a.m.